==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/sr.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Складиште није доступно",
    "Storage invalid" : "Неисправно складиште",
    "Unknown error" : "Непозната грешка",
    "Could not move %s - File with this name already exists" : "Не могу да преместим %s – фајл са овим називом већ постоји",
    "Could not move %s" : "Не могу да преместим %s",
    "Permission denied" : "Приступ одбијен",
    "The target folder has been moved or deleted." : "Одредишна фасцикла је премештена или обрисана.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Назив %s се већ користи у фасцикли %s. Одредите други назив.",
    "Error when creating the file" : "Грешка при стварању фајла",
    "Error when creating the folder" : "Грешка при стварању фајла",
    "Unable to set upload directory." : "Не могу да поставим директоријум за отпремање.",
    "Invalid Token" : "Неисправан токен",
    "No file was uploaded. Unknown error" : "Ниједан фајл није отпремљен. Непозната грешка",
    "There is no error, the file uploaded with success" : "Нема грешке, фајл је успешно отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Отпремани фајл превазилази смерницу upload_max_filesize у фајлу php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE која је наведена у ХТМЛ обрасцу",
    "The uploaded file was only partially uploaded" : "Отпремани фајл је само делимично отпремљен",
    "No file was uploaded" : "Ништа није отпремљено",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Failed to write to disk" : "Не могу да пишем на диск",
    "Not enough storage available" : "Нема довољно простора",
    "Upload failed. Could not find uploaded file" : "Неуспешно отпремање. Не могу да нађем отпремљени фајл",
    "Upload failed. Could not get file info." : "Неуспешно отпремање. Не могу да добијем податке о фајлу.",
    "Invalid directory." : "Неисправна фасцикла.",
    "Files" : "Фајлови",
    "All files" : "Сви фајлови",
    "Favorites" : "Омиљени",
    "Home" : "Почетна",
    "Close" : "Затвори",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Не могу да отпремим {filename} јер је то директоријум или има 0 бајтова",
    "Total file size {size1} exceeds upload limit {size2}" : "Величина {size1} превазилази ограничење за отпремање од {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема простора. Отпремате {size1} али само {size2} је преостало",
    "Upload cancelled." : "Отпремање је отказано.",
    "Could not get result from server." : "Не могу да добијем резултат са сервера.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Отпремање фајла је у току. Ако сада напустите страницу, отказаћете отпремање.",
    "Actions" : "Радње",
    "Download" : "Преузми",
    "Rename" : "Преименуј",
    "Delete" : "Обриши",
    "Details" : "Подаци",
    "Select" : "Изабери",
    "Pending" : "На чекању",
    "Unable to determine date" : "Не могу да одредим датум",
    "This operation is forbidden" : "Ова радња је забрањена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите записе или контактирајте администратора",
    "Error moving file." : "Грешка при премештању фајла.",
    "Error moving file" : "Грешка при премештању фајла",
    "Error" : "Грешка",
    "{new_name} already exists" : "{new_name} већ постоји",
    "Could not rename file" : "Не могу да преименујем фајл",
    "Could not create file" : "Не могу да створим фајл",
    "Could not create folder" : "Не могу да створим фасциклу",
    "Error deleting file." : "Грешка при брисању фајла.",
    "No entries in this folder match '{filter}'" : "У овој фасцикли ништа се не поклапа са '{filter}'",
    "Name" : "Назив",
    "Size" : "Величина",
    "Modified" : "Измењен",
    "_%n folder_::_%n folders_" : ["%n фасцикла","%n фасцикле","%n фасцикли"],
    "_%n file_::_%n files_" : ["%n фајл","%n фајла","%n фајлова"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "You don’t have permission to upload or create files here" : "Немате дозволе да овде отпремате или стварате фајлове",
    "_Uploading %n file_::_Uploading %n files_" : ["Отпремам %n фајл","Отпремам %n фајла","Отпремам %n фајлова"],
    "New" : "Ново",
    "\"{name}\" is an invalid file name." : "\"{name}\" није исправан назив фајла.",
    "File name cannot be empty." : "Назив фајла не може бити празан.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Складиште корисника {owner} је пуно. Фајлови се не могу ажурирати нити синхронизовати!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше складиште је пуно. Фајлови више не могу бити ажурирани ни синхронизовани!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Складиште корисника {owner} је скоро пуно ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше складиште је скоро пуно ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["се поклапа са '{filter}'","се поклапају са '{filter}'","се поклапа са '{filter}'"],
    "Path" : "Путања",
    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајта","%n бајта"],
    "Favorited" : "Омиљено",
    "Favorite" : "Омиљени",
    "{newname} already exists" : "{newname} већ постоји",
    "Upload" : "Отпреми",
    "Text file" : "текстуални фајл",
    "New text file.txt" : "Нов текстуални фајл.txt",
    "Folder" : "фасцикла",
    "New folder" : "Нова фасцикла",
    "An error occurred while trying to update the tags" : "Дошло је до грешке при покушају ажурирања ознака",
    "A new file or folder has been <strong>created</strong>" : "Нови фајл или фасцикла су <strong>направљени</strong>",
    "A file or folder has been <strong>changed</strong>" : "Фајл или фасцикла су <strong>измењени</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничи обавештења о стварању и изменама на <strong>омиљене фајлове</strong> <em>(само у записнику)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Фајл или фасцикла су <strong>обрисани</strong>",
    "A file or folder has been <strong>restored</strong>" : "Фајл или фасцикла су <strong>враћени</strong>",
    "You created %1$s" : "Направили сте %1$s",
    "%2$s created %1$s" : "%2$s направи %1$s",
    "%1$s was created in a public folder" : "%1$s је направљен у јавној фасцикли",
    "You changed %1$s" : "Изменили сте %1$s",
    "%2$s changed %1$s" : "%2$s измени %1$s",
    "You deleted %1$s" : "Обрисали сте %1$s",
    "%2$s deleted %1$s" : "%2$s обриса %1$s",
    "You restored %1$s" : "Вратили сте %1$s",
    "%2$s restored %1$s" : "%2$s поврати %1$s",
    "Changed by %2$s" : "Изменио %2$s",
    "Deleted by %2$s" : "Обрисао %2$s",
    "Restored by %2$s" : "Повратио %2$s",
    "%s could not be renamed as it has been deleted" : "%s се не може преименовати јер је обрисан",
    "%s could not be renamed" : "%s се не може преименовати",
    "Upload (max. %s)" : "Отпремање (макс. %s)",
    "File handling" : "Руковање фајловима",
    "Maximum upload size" : "Највећа величина отпремања",
    "max. possible: " : "највише могуће:",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "У PHP-FPM-у ова вредност има ефекта тек након 5 минута након примене.",
    "Save" : "Сачувај",
    "Can not be edited from here due to insufficient permissions." : "Не може да се мења одавде због недостатка дозвола.",
    "Settings" : "Поставке",
    "WebDAV" : "ВебДАВ",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Користите ову адресу да <a href=\"%s\" target=\"_blank\"> приступите фајловима преко ВебДАВ-а</a>",
    "Cancel upload" : "Откажи отпремање",
    "No files in here" : "Овде нема фајлова",
    "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
    "No entries found in this folder" : "Нема ничега у овој фасцикли",
    "Select all" : "Означи све",
    "Upload too large" : "Отпремање је превелико",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
    "Files are being scanned, please wait." : "Скенирам фајлове, сачекајте.",
    "Currently scanning" : "Тренутно скенирам",
    "No favorites" : "Нема омиљених",
    "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/sr.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Складиште није доступно",
    "Storage invalid" : "Неисправно складиште",
    "Unknown error" : "Непозната грешка",
    "Unable to set upload directory." : "Не могу да поставим директоријум за отпремање.",
    "Invalid Token" : "Неисправан токен",
    "No file was uploaded. Unknown error" : "Ниједан фајл није отпремљен. Непозната грешка",
    "There is no error, the file uploaded with success" : "Нема грешке, фајл је успешно отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Отпремани фајл превазилази смерницу upload_max_filesize у фајлу php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE која је наведена у ХТМЛ обрасцу",
    "The uploaded file was only partially uploaded" : "Отпремани фајл је само делимично отпремљен",
    "No file was uploaded" : "Ништа није отпремљено",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Failed to write to disk" : "Не могу да пишем на диск",
    "Not enough storage available" : "Нема довољно простора",
    "The target folder has been moved or deleted." : "Одредишна фасцикла је премештена или обрисана.",
    "Upload failed. Could not find uploaded file" : "Неуспешно отпремање. Не могу да нађем отпремљени фајл",
    "Upload failed. Could not get file info." : "Неуспешно отпремање. Не могу да добијем податке о фајлу.",
    "Invalid directory." : "Неисправна фасцикла.",
    "Files" : "Фајлови",
    "All files" : "Сви фајлови",
    "Favorites" : "Омиљени",
    "Home" : "Почетна",
    "Close" : "Затвори",
    "Upload cancelled." : "Отпремање је отказано.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Не могу да отпремим {filename} јер је то директоријум или има 0 бајтова",
    "Total file size {size1} exceeds upload limit {size2}" : "Величина {size1} превазилази ограничење за отпремање од {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема простора. Отпремате {size1} али само {size2} је преостало",
    "Could not get result from server." : "Не могу да добијем резултат са сервера.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Отпремање фајла је у току. Ако сада напустите страницу, отказаћете отпремање.",
    "Actions" : "Радње",
    "Download" : "Преузми",
    "Rename" : "Преименуј",
    "Delete" : "Обриши",
    "Disconnect storage" : "Искључи складиште",
    "Unshare" : "Не дели",
    "Details" : "Подаци",
    "Select" : "Изабери",
    "Pending" : "На чекању",
    "Unable to determine date" : "Не могу да одредим датум",
    "This operation is forbidden" : "Ова радња је забрањена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите записе или контактирајте администратора",
    "No entries in this folder match '{filter}'" : "У овој фасцикли ништа се не поклапа са '{filter}'",
    "Name" : "Назив",
    "Size" : "Величина",
    "Modified" : "Измењен",
    "_%n folder_::_%n folders_" : ["%n фасцикла","%n фасцикле","%n фасцикли"],
    "_%n file_::_%n files_" : ["%n фајл","%n фајла","%n фајлова"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "You don’t have permission to upload or create files here" : "Немате дозволе да овде отпремате или стварате фајлове",
    "_Uploading %n file_::_Uploading %n files_" : ["Отпремам %n фајл","Отпремам %n фајла","Отпремам %n фајлова"],
    "New" : "Ново",
    "\"{name}\" is an invalid file name." : "\"{name}\" није исправан назив фајла.",
    "File name cannot be empty." : "Назив фајла не може бити празан.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Складиште корисника {owner} је пуно. Фајлови се не могу ажурирати нити синхронизовати!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше складиште је пуно. Фајлови више не могу бити ажурирани ни синхронизовани!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Складиште корисника {owner} је скоро пуно ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше складиште је скоро пуно ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["се поклапа са '{filter}'","се поклапају са '{filter}'","се поклапа са '{filter}'"],
    "Path" : "Путања",
    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајта","%n бајта"],
    "Favorited" : "Омиљено",
    "Favorite" : "Омиљени",
    "Folder" : "фасцикла",
    "New folder" : "Нова фасцикла",
    "{newname} already exists" : "{newname} већ постоји",
    "Upload" : "Отпреми",
    "An error occurred while trying to update the tags" : "Дошло је до грешке при покушају ажурирања ознака",
    "A new file or folder has been <strong>created</strong>" : "Нови фајл или фасцикла су <strong>направљени</strong>",
    "A file or folder has been <strong>changed</strong>" : "Фајл или фасцикла су <strong>измењени</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничи обавештења о стварању и изменама на <strong>омиљене фајлове</strong> <em>(само у записнику)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Фајл или фасцикла су <strong>обрисани</strong>",
    "A file or folder has been <strong>restored</strong>" : "Фајл или фасцикла су <strong>враћени</strong>",
    "You created %1$s" : "Направили сте %1$s",
    "%2$s created %1$s" : "%2$s направи %1$s",
    "%1$s was created in a public folder" : "%1$s је направљен у јавној фасцикли",
    "You changed %1$s" : "Изменили сте %1$s",
    "%2$s changed %1$s" : "%2$s измени %1$s",
    "You deleted %1$s" : "Обрисали сте %1$s",
    "%2$s deleted %1$s" : "%2$s обриса %1$s",
    "You restored %1$s" : "Вратили сте %1$s",
    "%2$s restored %1$s" : "%2$s поврати %1$s",
    "Changed by %2$s" : "Изменио %2$s",
    "Deleted by %2$s" : "Обрисао %2$s",
    "Restored by %2$s" : "Повратио %2$s",
    "Upload (max. %s)" : "Отпремање (макс. %s)",
    "File handling" : "Руковање фајловима",
    "Maximum upload size" : "Највећа величина отпремања",
    "max. possible: " : "највише могуће:",
    "Save" : "Сачувај",
    "Settings" : "Поставке",
    "WebDAV" : "ВебДАВ",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Користите ову адресу да <a href=\"%s\" target=\"_blank\"> приступите фајловима преко ВебДАВ-а</a>",
    "Cancel upload" : "Откажи отпремање",
    "No files in here" : "Овде нема фајлова",
    "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
    "No entries found in this folder" : "Нема ничега у овој фасцикли",
    "Select all" : "Означи све",
    "Upload too large" : "Отпремање је превелико",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
    "No favorites" : "Нема омиљених",
    "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде",
    "Text file" : "текстуални фајл",
    "New text file.txt" : "Нов текстуални фајл.txt"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
